jackdaw.schema-registry

Management operations for a Confluent Schema Registry.

Functions in this namespace operate on a io.confluent.kafka.schemaregistry.client.SchemaRegistryClient, so callers can use either a real HTTP client or the Confluent mock client in tests.

Management operations for a Confluent Schema Registry.

Functions in this namespace operate on a
`io.confluent.kafka.schemaregistry.client.SchemaRegistryClient`, so callers
can use either a real HTTP client or the Confluent mock client in tests.
raw docstring

clientclj

(client url max-capacity)

Create a cached HTTP Schema Registry client.

Create a cached HTTP Schema Registry client.
sourceraw docstring

client?clj

(client? x)

Return true when x is a Schema Registry client.

Return true when x is a Schema Registry client.
sourceraw docstring

compatible?clj

(compatible? client subject schema)

Return whether schema is compatible with the subject's latest version.

Return whether schema is compatible with the subject's latest version.
sourceraw docstring

delete-schema-version!clj

(delete-schema-version! client subject version)
(delete-schema-version! client subject version permanent?)

Delete one schema version and return the deleted version.

Delete one schema version and return the deleted version.
sourceraw docstring

delete-subject!clj

(delete-subject! client subject)
(delete-subject! client subject permanent?)

Delete a subject and return its deleted version numbers.

Delete a subject and return its deleted version numbers.
sourceraw docstring

get-configclj

(get-config client subject)

Return subject configuration as a Clojure map.

Pass the empty subject to read the global configuration.

Return subject configuration as a Clojure map.

Pass the empty subject to read the global configuration.
sourceraw docstring

list-subjectsclj

(list-subjects client)

Return all registered subjects in deterministic order.

Return all registered subjects in deterministic order.
sourceraw docstring

register-schema!clj

(register-schema! client subject schema)

Register a ParsedSchema under subject and return its integer ID.

Register a ParsedSchema under subject and return its integer ID.
sourceraw docstring

schema-versionclj

(schema-version client subject schema)

Return the version of schema registered under subject.

Return the version of schema registered under subject.
sourceraw docstring

schema-versionsclj

(schema-versions client subject)

Return all registered versions for subject.

Return all registered versions for subject.
sourceraw docstring

set-config!clj

(set-config! client subject config)

Set subject configuration and return the resulting configuration map.

Set subject configuration and return the resulting configuration map.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries