jackdaw.serdes.fn

FIXME

FIXME
raw docstring

new-deserializerclj

(new-deserializer args)

Returns a Kafka Deserializer backed by the functions in args: required :deserialize (fn of [topic data]) and optional :close / :configure.

Returns a Kafka Deserializer backed by the functions in `args`: required
`:deserialize` (fn of [topic data]) and optional `:close` / `:configure`.
sourceraw docstring

new-serializerclj

(new-serializer args)

Returns a Kafka Serializer backed by the functions in args: required :serialize (fn of [topic data]) and optional :close / :configure.

Returns a Kafka Serializer backed by the functions in `args`: required
`:serialize` (fn of [topic data]) and optional `:close` / `:configure`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries