jackdaw.streams.interop

Clojure wrapper to kafka streams.

Clojure wrapper to kafka streams.
raw docstring

clj-global-ktableclj

(clj-global-ktable global-ktable)

Makes a CljKTable object.

Makes a CljKTable object.
sourceraw docstring

clj-kgroupedstreamclj

(clj-kgroupedstream kgroupedstream)

Makes a CljKGroupedStream object.

Makes a CljKGroupedStream object.
sourceraw docstring

clj-kgroupedtableclj

(clj-kgroupedtable kgroupedtable)

Makes a CljKGroupedTable object.

Makes a CljKGroupedTable object.
sourceraw docstring

clj-kstreamclj

(clj-kstream kstream)

Makes a CljKStream object.

Makes a CljKStream object.
sourceraw docstring

clj-ktableclj

(clj-ktable ktable)

Makes a CljKTable object.

Makes a CljKTable object.
sourceraw docstring

clj-session-windowed-kstreamclj

(clj-session-windowed-kstream windowed-kstream)

Makes a CljSessionWindowedKStream object.

Makes a CljSessionWindowedKStream object.
sourceraw docstring

clj-time-windowed-kstreamclj

(clj-time-windowed-kstream windowed-kstream)

Makes a CljTimeWindowedKStream object.

Makes a CljTimeWindowedKStream object.
sourceraw docstring

streams-builderclj

(streams-builder)

Makes a streams builder.

Makes a streams builder.
sourceraw docstring

suppress-config->suppressedclj

(suppress-config->suppressed {:keys [max-records max-bytes
                                     until-time-limit-ms]})

Builds a Kafka Streams Suppressed from a suppression config, choosing the buffer bound from :max-records, :max-bytes, or :until-time-limit-ms.

Builds a Kafka Streams `Suppressed` from a suppression config, choosing the
buffer bound from `:max-records`, `:max-bytes`, or `:until-time-limit-ms`.
sourceraw docstring

topic->consumedclj

(topic->consumed {:keys [key-serde value-serde]})

Builds a Kafka Streams Consumed from a topic config's :key-serde and :value-serde.

Builds a Kafka Streams `Consumed` from a topic config's `:key-serde` and
`:value-serde`.
sourceraw docstring

topic->groupedclj

(topic->grouped {:keys [key-serde value-serde]})

Builds a Kafka Streams Grouped from a topic config's :key-serde and :value-serde.

Builds a Kafka Streams `Grouped` from a topic config's `:key-serde` and
`:value-serde`.
sourceraw docstring

topic->materializedclj

(topic->materialized {:keys [topic-name key-serde value-serde]})

Builds a Kafka Streams Materialized store named by :topic-name, applying the topic config's key/value serdes when present.

Builds a Kafka Streams `Materialized` store named by `:topic-name`, applying
the topic config's key/value serdes when present.
sourceraw docstring

topic->producedclj

(topic->produced {:keys [key-serde value-serde partition-fn]})

Builds a Kafka Streams Produced from a topic config's serdes, attaching a custom stream partitioner when :partition-fn is present.

Builds a Kafka Streams `Produced` from a topic config's serdes, attaching a
custom stream partitioner when `:partition-fn` is present.
sourceraw docstring

topic->repartitionedclj

(topic->repartitioned {:keys [topic-name key-serde value-serde partition-fn]})

Builds a Kafka Streams Repartitioned from a topic config's serdes, applying :topic-name and a :partition-fn partitioner when present.

Builds a Kafka Streams `Repartitioned` from a topic config's serdes, applying
`:topic-name` and a `:partition-fn` partitioner when present.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries