jackdaw.test.fixtures


default-reset-fnclj

(default-reset-fn rt args)

Runs Kafka's StreamsResetter rt with the string args vector to reset an application's offsets and internal topics.

Runs Kafka's StreamsResetter `rt` with the string `args` vector to reset an
application's offsets and internal topics.
sourceraw docstring

delete-recursivelyclj

(delete-recursively fname)

Recursively deletes the file or directory fname and its contents.

Recursively deletes the file or directory `fname` and its contents.
sourceraw docstring

empty-state-fixtureclj

(empty-state-fixture app-config)

Returns a clojure.test fixture fn that deletes the Kafka Streams local state directory for app-config's application id before running the test.

Returns a clojure.test fixture fn that deletes the Kafka Streams local state
directory for `app-config`'s application id before running the test.
sourceraw docstring

integration-fixtureclj

(integration-fixture build-fn
                     {:keys [broker-config topic-metadata app-config enable?]})

Returns a joined clojure.test fixture. When :enable? is truthy it provisions :topic-metadata against :broker-config, resets the application, and starts the topology built by (build-fn topic-metadata); otherwise it only clears local state.

Returns a joined clojure.test fixture. When `:enable?` is truthy it provisions
`:topic-metadata` against `:broker-config`, resets the application, and starts
the topology built by `(build-fn topic-metadata)`; otherwise it only clears
local state.
sourceraw docstring

kstream-fixtureclj

(kstream-fixture {:keys [topology config]})

Returns a fixture that builds and starts kafka streams for the supplied topology before running the test function (and then tears it down when the test is complete).

compose-fixtures or join-fixtures may be used to build fixtures combine topologies

Returns a fixture that builds and starts kafka streams for the supplied topology
before running the test function (and then tears it down when the test is
complete).

`compose-fixtures` or `join-fixtures` may be used to build fixtures combine
topologies
sourceraw docstring

list-topicsclj

(list-topics client)

Returns the AdminClient ListTopicsResult for client.

Returns the AdminClient ListTopicsResult for `client`.
sourceraw docstring

reset-application-fixtureclj

(reset-application-fixture app-config)
(reset-application-fixture app-config reset-args)
(reset-application-fixture app-config reset-args reset-fn)

Returns a fixture that runs the org.apache.kafka.tools.StreamsResetter with the supplied reset-args as parameters

Returns a fixture that runs the org.apache.kafka.tools.StreamsResetter with the
supplied `reset-args` as parameters
sourceraw docstring

service-ready?clj

(service-ready? {:keys [http-url http-params timeout]})

Returns a clojure.test fixture fn that polls :http-url (with :http-params) until it responds 200, within :timeout ms, then runs the test; throws if the service never becomes ready.

Returns a clojure.test fixture fn that polls `:http-url` (with `:http-params`)
until it responds 200, within `:timeout` ms, then runs the test; throws if the
service never becomes ready.
sourceraw docstring

skip-to-endclj

(skip-to-end {:keys [topic config]})

Returns a fixture that skips to the end of the supplied topic before running the test function

Returns a fixture that skips to the end of the supplied topic before running
the test function
sourceraw docstring

topic-fixtureclj

(topic-fixture kafka-config topic-config)
(topic-fixture kafka-config topic-config timeout-ms)

Returns a fixture function that creates all the topics named in the supplied topic config before running a test function.

Returns a fixture function that creates all the topics named in the supplied
topic config before running a test function.
sourceraw docstring

with-fixturescljmacro

(with-fixtures fixtures & body)

Runs body with the joined clojure.test fixtures applied around it.

Runs `body` with the joined clojure.test `fixtures` applied around it.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries