A test machine executor can be built by composing execution wrappers defined in here
A test machine executor can be built by composing execution wrappers defined in here
(with-journal-snapshots f)Journal middleware. Adds journal snapshots before/after the operation to the response map
Journal middleware. Adds journal snapshots before/after the operation to the response map
(with-status f)Command-handler middleware: wraps handler f so each result map is tagged
with :status :error when it contains an :error, otherwise :status :ok.
Command-handler middleware: wraps handler `f` so each result map is tagged with `:status :error` when it contains an `:error`, otherwise `:status :ok`.
(with-timing f)Timing middleware. Adds timing information to the response map
Timing middleware. Adds timing information to the response map
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |