jackdaw.test.serde


apply-deserializersclj

(apply-deserializers deserializers m)

Deserializes record m using the deserializer registered for its topic in deserializers; throws IllegalArgumentException for an unknown topic.

Deserializes record `m` using the deserializer registered for its topic in
`deserializers`; throws IllegalArgumentException for an unknown topic.
sourceraw docstring

apply-serializersclj

(apply-serializers serializers m)

Serializes message m using the serializer registered for its topic in serializers; throws IllegalArgumentException for an unknown topic.

Serializes message `m` using the serializer registered for its topic in
`serializers`; throws IllegalArgumentException for an unknown topic.
sourceraw docstring

byte-array-deserializerclj

source

byte-array-serdeclj

Byte-array key and value serde.

Byte-array key and value serde.
sourceraw docstring

byte-array-serializerclj

source

deserialize-keyclj

(deserialize-key k {topic-name :topic-name key-serde :key-serde})

Deserializes a key.

Deserializes a key.
sourceraw docstring

deserialize-valueclj

(deserialize-value v {topic-name :topic-name value-serde :value-serde})

Deserializes a value.

Deserializes a value.
sourceraw docstring

deserializerclj

(deserializer topic)

Deserializes a message.

Deserializes a message.
sourceraw docstring

deserializersclj

(deserializers topic-config)

Returns a map of topics to the corresponding deserializer

Returns a map of topics to the corresponding deserializer
sourceraw docstring

resolverclj

(resolver topic-config)

Returns a fn that resolves a serde keyword (:edn, :json, :long, :string, ...) in topic-config to a concrete Kafka serde instance.

Returns a fn that resolves a serde keyword (:edn, :json, :long, :string, ...)
in `topic-config` to a concrete Kafka serde instance.
sourceraw docstring

serde-mapclj

(serde-map topic-config)

Returns {:serializers _ :deserializers _}, each a map of topic-name to the corresponding serializer/deserializer fn for topic-config.

Returns `{:serializers _ :deserializers _}`, each a map of topic-name to the
corresponding serializer/deserializer fn for `topic-config`.
sourceraw docstring

serialize-keyclj

(serialize-key k {topic-name :topic-name key-serde :key-serde :as t})

Serializes a key.

Serializes a key.
sourceraw docstring

serialize-valueclj

(serialize-value v {topic-name :topic-name value-serde :value-serde :as t})

Serializes value v for topic t using its :value-serde, returning nil when v is nil.

Serializes value `v` for topic `t` using its `:value-serde`, returning nil
when `v` is nil.
sourceraw docstring

serializerclj

(serializer topic)

Serializes a message.

Serializes a message.
sourceraw docstring

serializersclj

(serializers topic-config)

Returns a map of topic to the corresponding serializer

Returns a map of topic to the corresponding serializer
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries