jackdaw.test.transports.identity


identity-consumerclj

(identity-consumer stream)

Builds an identity-transport consumer that reads directly from stream, bypassing Kafka (used to feed produced records straight back to the machine).

Builds an identity-transport consumer that reads directly from `stream`,
bypassing Kafka (used to feed produced records straight back to the machine).
sourceraw docstring

identity-producerclj

(identity-producer)

Builds an identity-transport producer backed by a fresh in-memory stream, bypassing Kafka.

Builds an identity-transport producer backed by a fresh in-memory stream,
bypassing Kafka.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries