Management operations for a Confluent Schema Registry.
Functions in this namespace operate on a
io.confluent.kafka.schemaregistry.client.SchemaRegistryClient, so callers
can use either a real HTTP client or the Confluent mock client in tests.
Management operations for a Confluent Schema Registry. Functions in this namespace operate on a `io.confluent.kafka.schemaregistry.client.SchemaRegistryClient`, so callers can use either a real HTTP client or the Confluent mock client in tests.
(client url max-capacity)Create a cached HTTP Schema Registry client.
Create a cached HTTP Schema Registry client.
(client? x)Return true when x is a Schema Registry client.
Return true when x is a Schema Registry client.
(compatible? client subject schema)Return whether schema is compatible with the subject's latest version.
Return whether schema is compatible with the subject's latest version.
(delete-schema-version! client subject version)(delete-schema-version! client subject version permanent?)Delete one schema version and return the deleted version.
Delete one schema version and return the deleted version.
(delete-subject! client subject)(delete-subject! client subject permanent?)Delete a subject and return its deleted version numbers.
Delete a subject and return its deleted version numbers.
(get-config client subject)Return subject configuration as a Clojure map.
Pass the empty subject to read the global configuration.
Return subject configuration as a Clojure map. Pass the empty subject to read the global configuration.
(list-subjects client)Return all registered subjects in deterministic order.
Return all registered subjects in deterministic order.
(register-schema! client subject schema)Register a ParsedSchema under subject and return its integer ID.
Register a ParsedSchema under subject and return its integer ID.
(schema-version client subject schema)Return the version of schema registered under subject.
Return the version of schema registered under subject.
(schema-versions client subject)Return all registered versions for subject.
Return all registered versions for subject.
(set-config! client subject config)Set subject configuration and return the resulting configuration map.
Set subject configuration and return the resulting configuration map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |