FIXME
FIXME
(new-deserializer args)Returns a Kafka Deserializer backed by the functions in args: required
:deserialize (fn of [topic data]) and optional :close / :configure.
Returns a Kafka Deserializer backed by the functions in `args`: required `:deserialize` (fn of [topic data]) and optional `:close` / `:configure`.
(new-serializer args)Returns a Kafka Serializer backed by the functions in args: required
:serialize (fn of [topic data]) and optional :close / :configure.
Returns a Kafka Serializer backed by the functions in `args`: required `:serialize` (fn of [topic data]) and optional `:close` / `:configure`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |