FIXME
FIXME
(logging-state-restore-listener)Returns a new Kafka StateRestoreListener instance which logs when
batches are restored, and how long it takes to restore all the
batches for a given partition.
Returns a new Kafka `StateRestoreListener` instance which logs when batches are restored, and how long it takes to restore all the batches for a given partition.
(map-validating! builder topic topic-spec {:keys [line file]})Adds a map-values stage to builder that validates each outbound record
against topic-spec, throwing (and logging) an ex-info with the explain-data
and the :line/:file source location if a record is invalid.
Adds a map-values stage to `builder` that validates each outbound record against `topic-spec`, throwing (and logging) an ex-info with the explain-data and the `:line`/`:file` source location if a record is invalid.
(through builder topic topic-spec)(through builder partition-fn topic topic-spec)Wraps #'jackdaw.streams/through, providing validation of records
against the spec of the through topic.
Wraps `#'jackdaw.streams/through`, providing validation of records against the spec of the through topic.
(to! builder topic topic-spec)(to! builder partition-fn topic topic-spec)Wraps #'jackdaw.streams/to!, providing validation of records
against the spec of the to! topic.
Wraps `#'jackdaw.streams/to!`, providing validation of records against the spec of the to! topic.
(with-file form-meta)Returns form-meta with its :file defaulted to the current *file* when
absent, so macro-captured source locations survive expansion.
Returns `form-meta` with its `:file` defaulted to the current `*file*` when absent, so macro-captured source locations survive expansion.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |