Clojure wrapper to kafka streams.
Clojure wrapper to kafka streams.
(clj-global-ktable global-ktable)Makes a CljKTable object.
Makes a CljKTable object.
(clj-kgroupedstream kgroupedstream)Makes a CljKGroupedStream object.
Makes a CljKGroupedStream object.
(clj-kgroupedtable kgroupedtable)Makes a CljKGroupedTable object.
Makes a CljKGroupedTable object.
(clj-kstream kstream)Makes a CljKStream object.
Makes a CljKStream object.
(clj-ktable ktable)Makes a CljKTable object.
Makes a CljKTable object.
(clj-session-windowed-kstream windowed-kstream)Makes a CljSessionWindowedKStream object.
Makes a CljSessionWindowedKStream object.
(clj-time-windowed-kstream windowed-kstream)Makes a CljTimeWindowedKStream object.
Makes a CljTimeWindowedKStream object.
(streams-builder)Makes a streams builder.
Makes a streams builder.
(suppress-config->suppressed {:keys [max-records max-bytes
until-time-limit-ms]})Builds a Kafka Streams Suppressed from a suppression config, choosing the
buffer bound from :max-records, :max-bytes, or :until-time-limit-ms.
Builds a Kafka Streams `Suppressed` from a suppression config, choosing the buffer bound from `:max-records`, `:max-bytes`, or `:until-time-limit-ms`.
(topic->consumed {:keys [key-serde value-serde]})Builds a Kafka Streams Consumed from a topic config's :key-serde and
:value-serde.
Builds a Kafka Streams `Consumed` from a topic config's `:key-serde` and `:value-serde`.
(topic->grouped {:keys [key-serde value-serde]})Builds a Kafka Streams Grouped from a topic config's :key-serde and
:value-serde.
Builds a Kafka Streams `Grouped` from a topic config's `:key-serde` and `:value-serde`.
(topic->materialized {:keys [topic-name key-serde value-serde]})Builds a Kafka Streams Materialized store named by :topic-name, applying
the topic config's key/value serdes when present.
Builds a Kafka Streams `Materialized` store named by `:topic-name`, applying the topic config's key/value serdes when present.
(topic->produced {:keys [key-serde value-serde partition-fn]})Builds a Kafka Streams Produced from a topic config's serdes, attaching a
custom stream partitioner when :partition-fn is present.
Builds a Kafka Streams `Produced` from a topic config's serdes, attaching a custom stream partitioner when `:partition-fn` is present.
(topic->repartitioned {:keys [topic-name key-serde value-serde partition-fn]})Builds a Kafka Streams Repartitioned from a topic config's serdes, applying
:topic-name and a :partition-fn partitioner when present.
Builds a Kafka Streams `Repartitioned` from a topic config's serdes, applying `:topic-name` and a `:partition-fn` partitioner when present.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |