(apply-deserializers deserializers m)Deserializes record m using the deserializer registered for its topic in
deserializers; throws IllegalArgumentException for an unknown topic.
Deserializes record `m` using the deserializer registered for its topic in `deserializers`; throws IllegalArgumentException for an unknown topic.
(apply-serializers serializers m)Serializes message m using the serializer registered for its topic in
serializers; throws IllegalArgumentException for an unknown topic.
Serializes message `m` using the serializer registered for its topic in `serializers`; throws IllegalArgumentException for an unknown topic.
Byte-array key and value serde.
Byte-array key and value serde.
(deserialize-key k {topic-name :topic-name key-serde :key-serde})Deserializes a key.
Deserializes a key.
(deserialize-value v {topic-name :topic-name value-serde :value-serde})Deserializes a value.
Deserializes a value.
(deserializer topic)Deserializes a message.
Deserializes a message.
(deserializers topic-config)Returns a map of topics to the corresponding deserializer
Returns a map of topics to the corresponding deserializer
(resolver topic-config)Returns a fn that resolves a serde keyword (:edn, :json, :long, :string, ...)
in topic-config to a concrete Kafka serde instance.
Returns a fn that resolves a serde keyword (:edn, :json, :long, :string, ...) in `topic-config` to a concrete Kafka serde instance.
(serde-map topic-config)Returns {:serializers _ :deserializers _}, each a map of topic-name to the
corresponding serializer/deserializer fn for topic-config.
Returns `{:serializers _ :deserializers _}`, each a map of topic-name to the
corresponding serializer/deserializer fn for `topic-config`.(serialize-key k {topic-name :topic-name key-serde :key-serde :as t})Serializes a key.
Serializes a key.
(serialize-value v {topic-name :topic-name value-serde :value-serde :as t})Serializes value v for topic t using its :value-serde, returning nil
when v is nil.
Serializes value `v` for topic `t` using its `:value-serde`, returning nil when `v` is nil.
(serializers topic-config)Returns a map of topic to the corresponding serializer
Returns a map of topic to the corresponding serializer
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |