(identity-consumer stream)Builds an identity-transport consumer that reads directly from stream,
bypassing Kafka (used to feed produced records straight back to the machine).
Builds an identity-transport consumer that reads directly from `stream`, bypassing Kafka (used to feed produced records straight back to the machine).
(identity-producer)Builds an identity-transport producer backed by a fresh in-memory stream, bypassing Kafka.
Builds an identity-transport producer backed by a fresh in-memory stream, bypassing Kafka.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |